Class: Google::Apis::TpuV2::QueueingPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tpu_v2/classes.rb,
lib/google/apis/tpu_v2/representations.rb,
lib/google/apis/tpu_v2/representations.rb

Overview

Defines the policy of the QueuedRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueueingPolicy

Returns a new instance of QueueingPolicy.



1344
1345
1346
# File 'lib/google/apis/tpu_v2/classes.rb', line 1344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#valid_after_durationString

Optional. A relative time after which resources may be created. Corresponds to the JSON property validAfterDuration

Returns:

  • (String)


1317
1318
1319
# File 'lib/google/apis/tpu_v2/classes.rb', line 1317

def valid_after_duration
  @valid_after_duration
end

#valid_after_timeString

Optional. An absolute time after which resources may be created. Corresponds to the JSON property validAfterTime

Returns:

  • (String)


1322
1323
1324
# File 'lib/google/apis/tpu_v2/classes.rb', line 1322

def valid_after_time
  @valid_after_time
end

#valid_intervalGoogle::Apis::TpuV2::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property validInterval



1330
1331
1332
# File 'lib/google/apis/tpu_v2/classes.rb', line 1330

def valid_interval
  @valid_interval
end

#valid_until_durationString

Optional. A relative time after which resources should not be created. If the request cannot be fulfilled by this time the request will be failed. Corresponds to the JSON property validUntilDuration

Returns:

  • (String)


1336
1337
1338
# File 'lib/google/apis/tpu_v2/classes.rb', line 1336

def valid_until_duration
  @valid_until_duration
end

#valid_until_timeString

Optional. An absolute time after which resources should not be created. If the request cannot be fulfilled by this time the request will be failed. Corresponds to the JSON property validUntilTime

Returns:

  • (String)


1342
1343
1344
# File 'lib/google/apis/tpu_v2/classes.rb', line 1342

def valid_until_time
  @valid_until_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1349
1350
1351
1352
1353
1354
1355
# File 'lib/google/apis/tpu_v2/classes.rb', line 1349

def update!(**args)
  @valid_after_duration = args[:valid_after_duration] if args.key?(:valid_after_duration)
  @valid_after_time = args[:valid_after_time] if args.key?(:valid_after_time)
  @valid_interval = args[:valid_interval] if args.key?(:valid_interval)
  @valid_until_duration = args[:valid_until_duration] if args.key?(:valid_until_duration)
  @valid_until_time = args[:valid_until_time] if args.key?(:valid_until_time)
end