Class: Google::Apis::TpuV2::TPUService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::TpuV2::TPUService
- Defined in:
- lib/google/apis/tpu_v2/service.rb
Overview
Cloud TPU API
TPU API provides customers with access to Google TPU technology.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://tpu.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_node(parent, node_object = nil, node_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Creates a node.
-
#create_project_location_queued_resource(parent, queued_resource_object = nil, queued_resource_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Creates a QueuedResource TPU instance.
-
#delete_project_location_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Deletes a node.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Empty
Deletes a long-running operation.
-
#delete_project_location_queued_resource(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Deletes a QueuedResource TPU instance.
-
#generate_location_service_identity(parent, generate_service_identity_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::GenerateServiceIdentityResponse
Generates the Cloud TPU service identity for the project.
-
#get_node_guest_attributes(name, get_guest_attributes_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::GetGuestAttributesResponse
Retrieves the guest attributes for the node.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Location
Gets information about a location.
-
#get_project_location_accelerator_type(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::AcceleratorType
Gets AcceleratorType.
-
#get_project_location_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Node
Gets the details of a node.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_queued_resource(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::QueuedResource
Gets details of a queued resource.
-
#get_project_location_runtime_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::RuntimeVersion
Gets a runtime version.
-
#initialize ⇒ TPUService
constructor
A new instance of TPUService.
-
#list_project_location_accelerator_types(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::ListAcceleratorTypesResponse
Lists accelerator types supported by this API.
-
#list_project_location_nodes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::ListNodesResponse
Lists nodes.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_queued_resources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::ListQueuedResourcesResponse
Lists queued resources.
-
#list_project_location_runtime_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::ListRuntimeVersionsResponse
Lists runtime versions supported by this API.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_node(name, node_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Updates the configurations of a node.
-
#reset_queued_resource(name, reset_queued_resource_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Resets a QueuedResource TPU instance.
-
#start_node(name, start_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Starts a node.
-
#stop_node(name, stop_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Stops a node.
Constructor Details
#initialize ⇒ TPUService
Returns a new instance of TPUService.
47 48 49 50 51 52 |
# File 'lib/google/apis/tpu_v2/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-tpu_v2', client_version: Google::Apis::TpuV2::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/tpu_v2/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/tpu_v2/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
535 536 537 538 539 540 541 542 543 |
# File 'lib/google/apis/tpu_v2/service.rb', line 535 def cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:cancel', ) command.response_representation = Google::Apis::TpuV2::Empty::Representation command.response_class = Google::Apis::TpuV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_node(parent, node_object = nil, node_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Creates a node.
263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/google/apis/tpu_v2/service.rb', line 263 def create_project_location_node(parent, node_object = nil, node_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+parent}/nodes', ) command.request_representation = Google::Apis::TpuV2::Node::Representation command.request_object = node_object command.response_representation = Google::Apis::TpuV2::Operation::Representation command.response_class = Google::Apis::TpuV2::Operation command.params['parent'] = parent unless parent.nil? command.query['nodeId'] = node_id unless node_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_queued_resource(parent, queued_resource_object = nil, queued_resource_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Creates a QueuedResource TPU instance.
684 685 686 687 688 689 690 691 692 693 694 695 696 |
# File 'lib/google/apis/tpu_v2/service.rb', line 684 def create_project_location_queued_resource(parent, queued_resource_object = nil, queued_resource_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+parent}/queuedResources', ) command.request_representation = Google::Apis::TpuV2::QueuedResource::Representation command.request_object = queued_resource_object command.response_representation = Google::Apis::TpuV2::Operation::Representation command.response_class = Google::Apis::TpuV2::Operation command.params['parent'] = parent unless parent.nil? command.query['queuedResourceId'] = queued_resource_id unless queued_resource_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Deletes a node.
296 297 298 299 300 301 302 303 304 |
# File 'lib/google/apis/tpu_v2/service.rb', line 296 def delete_project_location_node(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::TpuV2::Operation::Representation command.response_class = Google::Apis::TpuV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
568 569 570 571 572 573 574 575 576 |
# File 'lib/google/apis/tpu_v2/service.rb', line 568 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::TpuV2::Empty::Representation command.response_class = Google::Apis::TpuV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_queued_resource(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Deletes a QueuedResource TPU instance.
726 727 728 729 730 731 732 733 734 735 736 |
# File 'lib/google/apis/tpu_v2/service.rb', line 726 def delete_project_location_queued_resource(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::TpuV2::Operation::Representation command.response_class = Google::Apis::TpuV2::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_location_service_identity(parent, generate_service_identity_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::GenerateServiceIdentityResponse
Generates the Cloud TPU service identity for the project.
75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/google/apis/tpu_v2/service.rb', line 75 def generate_location_service_identity(parent, generate_service_identity_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+parent}:generateServiceIdentity', ) command.request_representation = Google::Apis::TpuV2::GenerateServiceIdentityRequest::Representation command.request_object = generate_service_identity_request_object command.response_representation = Google::Apis::TpuV2::GenerateServiceIdentityResponse::Representation command.response_class = Google::Apis::TpuV2::GenerateServiceIdentityResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_node_guest_attributes(name, get_guest_attributes_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::GetGuestAttributesResponse
Retrieves the guest attributes for the node.
357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/google/apis/tpu_v2/service.rb', line 357 def get_node_guest_attributes(name, get_guest_attributes_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:getGuestAttributes', ) command.request_representation = Google::Apis::TpuV2::GetGuestAttributesRequest::Representation command.request_object = get_guest_attributes_request_object command.response_representation = Google::Apis::TpuV2::GetGuestAttributesResponse::Representation command.response_class = Google::Apis::TpuV2::GetGuestAttributesResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Location
Gets information about a location.
107 108 109 110 111 112 113 114 115 |
# File 'lib/google/apis/tpu_v2/service.rb', line 107 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::TpuV2::Location::Representation command.response_class = Google::Apis::TpuV2::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_accelerator_type(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::AcceleratorType
Gets AcceleratorType.
188 189 190 191 192 193 194 195 196 |
# File 'lib/google/apis/tpu_v2/service.rb', line 188 def get_project_location_accelerator_type(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::TpuV2::AcceleratorType::Representation command.response_class = Google::Apis::TpuV2::AcceleratorType command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Node
Gets the details of a node.
326 327 328 329 330 331 332 333 334 |
# File 'lib/google/apis/tpu_v2/service.rb', line 326 def get_project_location_node(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::TpuV2::Node::Representation command.response_class = Google::Apis::TpuV2::Node command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
599 600 601 602 603 604 605 606 607 |
# File 'lib/google/apis/tpu_v2/service.rb', line 599 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::TpuV2::Operation::Representation command.response_class = Google::Apis::TpuV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_queued_resource(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::QueuedResource
Gets details of a queued resource.
758 759 760 761 762 763 764 765 766 |
# File 'lib/google/apis/tpu_v2/service.rb', line 758 def get_project_location_queued_resource(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::TpuV2::QueuedResource::Representation command.response_class = Google::Apis::TpuV2::QueuedResource command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_runtime_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::RuntimeVersion
Gets a runtime version.
858 859 860 861 862 863 864 865 866 |
# File 'lib/google/apis/tpu_v2/service.rb', line 858 def get_project_location_runtime_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::TpuV2::RuntimeVersion::Representation command.response_class = Google::Apis::TpuV2::RuntimeVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_accelerator_types(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::ListAcceleratorTypesResponse
Lists accelerator types supported by this API.
226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/google/apis/tpu_v2/service.rb', line 226 def list_project_location_accelerator_types(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/acceleratorTypes', ) command.response_representation = Google::Apis::TpuV2::ListAcceleratorTypesResponse::Representation command.response_class = Google::Apis::TpuV2::ListAcceleratorTypesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_nodes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::ListNodesResponse
Lists nodes.
393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/google/apis/tpu_v2/service.rb', line 393 def list_project_location_nodes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/nodes', ) command.response_representation = Google::Apis::TpuV2::ListNodesResponse::Representation command.response_class = Google::Apis::TpuV2::ListNodesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
644 645 646 647 648 649 650 651 652 653 654 655 656 |
# File 'lib/google/apis/tpu_v2/service.rb', line 644 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}/operations', ) command.response_representation = Google::Apis::TpuV2::ListOperationsResponse::Representation command.response_class = Google::Apis::TpuV2::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_queued_resources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::ListQueuedResourcesResponse
Lists queued resources.
793 794 795 796 797 798 799 800 801 802 803 |
# File 'lib/google/apis/tpu_v2/service.rb', line 793 def list_project_location_queued_resources(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/queuedResources', ) command.response_representation = Google::Apis::TpuV2::ListQueuedResourcesResponse::Representation command.response_class = Google::Apis::TpuV2::ListQueuedResourcesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_runtime_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::ListRuntimeVersionsResponse
Lists runtime versions supported by this API.
896 897 898 899 900 901 902 903 904 905 906 907 908 |
# File 'lib/google/apis/tpu_v2/service.rb', line 896 def list_project_location_runtime_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/runtimeVersions', ) command.response_representation = Google::Apis::TpuV2::ListRuntimeVersionsResponse::Representation command.response_class = Google::Apis::TpuV2::ListRuntimeVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/google/apis/tpu_v2/service.rb', line 154 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}/locations', ) command.response_representation = Google::Apis::TpuV2::ListLocationsResponse::Representation command.response_class = Google::Apis::TpuV2::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_node(name, node_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Updates the configurations of a node.
429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/google/apis/tpu_v2/service.rb', line 429 def patch_project_location_node(name, node_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2/{+name}', ) command.request_representation = Google::Apis::TpuV2::Node::Representation command.request_object = node_object command.response_representation = Google::Apis::TpuV2::Operation::Representation command.response_class = Google::Apis::TpuV2::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#reset_queued_resource(name, reset_queued_resource_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Resets a QueuedResource TPU instance
826 827 828 829 830 831 832 833 834 835 836 |
# File 'lib/google/apis/tpu_v2/service.rb', line 826 def reset_queued_resource(name, reset_queued_resource_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:reset', ) command.request_representation = Google::Apis::TpuV2::ResetQueuedResourceRequest::Representation command.request_object = reset_queued_resource_request_object command.response_representation = Google::Apis::TpuV2::Operation::Representation command.response_class = Google::Apis::TpuV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_node(name, start_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Starts a node.
463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/google/apis/tpu_v2/service.rb', line 463 def start_node(name, start_node_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:start', ) command.request_representation = Google::Apis::TpuV2::StartNodeRequest::Representation command.request_object = start_node_request_object command.response_representation = Google::Apis::TpuV2::Operation::Representation command.response_class = Google::Apis::TpuV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#stop_node(name, stop_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV2::Operation
Stops a node. This operation is only available with single TPU nodes.
496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/google/apis/tpu_v2/service.rb', line 496 def stop_node(name, stop_node_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:stop', ) command.request_representation = Google::Apis::TpuV2::StopNodeRequest::Representation command.request_object = stop_node_request_object command.response_representation = Google::Apis::TpuV2::Operation::Representation command.response_class = Google::Apis::TpuV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |